@@ -7,6 +7,7 @@ from typing import cast
 import nbformat as nbf
 import nest_asyncio
 import pandas as pd
+from evalassist.judges.base import UnitxtInferenceEngineMixin
 from fastapi import (
     APIRouter,
     BackgroundTasks,
@@ -44,7 +45,8 @@ from .api_types import (
     FeatureFlagsModel,
     FixInstanceRequest,
     FixInstanceResponse,
-    InstanceResultDTO,
+    InstanceResultWithId,
+    JudgesResponseModel,
     NotebookParams,
     PairwiseInstanceDTO,
     PersonaEnum,
@@ -66,10 +68,9 @@ from .database import engine  # Assumes you have engine/session setup
 from .extended_unitxt import EXTENDED_EVALUATORS_METADATA
 from .judges import (
     DEFAULT_JUDGE_INFERENCE_PARAMS,
+    JUDGE_CLASS_MAP,
     Criteria,
-    DirectJudge,
     GraniteGuardianJudge,
-    PairwiseJudge,
 )
 from .model import AppUser, StoredTestCase
 from .notebook_generation import DirectEvaluationNotebook, PairwiseEvaluationNotebook
@@ -78,7 +79,6 @@ from .notebook_generation import DirectEvaluationNotebook, PairwiseEvaluationNot
 from .synthetic_example_generation.generate import DirectActionGenerator, Generator
 from .utils import (
     clean_object,
-    criteria_with_options_DTO_to_BO_mapper,
     get_custom_models,
     get_evaluator_metadata_wrapper,
     get_inference_engine_from_judge_metadata,
@@ -161,7 +161,7 @@ def get_feature_flags() -> dict[str, bool]:
 
 @router.get("/evaluators/", response_model=EvaluatorsResponseModel)
 def get_evaluators():
-    """Get the list of available pipelines, as supported by llm-as-a-judge library"""
+    """Get the list of available models"""
     evaluators = [
         EvaluatorMetadataAPI(**e.__dict__) for e in EXTENDED_EVALUATORS_METADATA
     ]
@@ -175,6 +175,14 @@ def get_evaluators():
     return EvaluatorsResponseModel(evaluators=evaluators)
 
 
+@router.get("/judges/", response_model=JudgesResponseModel)
+def get_judges():
+    """Get the list of available judges"""
+    return JudgesResponseModel(
+        judges={k: list(v.keys()) for k, v in JUDGE_CLASS_MAP.items()}
+    )
+
+
 @router.get("/default-credentials/", response_model=dict[str, dict[str, str]])
 def get_default_credentials():
     openai_api_key = os.getenv("EVALASSIST_OPENAI_API_KEY", None)
@@ -217,7 +225,7 @@ def get_default_credentials():
 
 
 @router.get("/criteria/")
-def get_criterias() -> dict[str, list[CriteriaWithOptionsDTO] | list[CriteriaDTO]]:
+def get_criteria() -> dict[str, list[CriteriaWithOptionsDTO] | list[CriteriaDTO]]:
     """Get the list of available criterias"""
     for c in [*DIRECT_CRITERIA, *PAIRWISE_CRITERIA]:
         if c.context_fields is None or c.prediction_field is None:
@@ -261,9 +269,7 @@ def get_prompt(req: EvaluationRequest):
     res = evaluator.get_prompt(
         instances=req.instances,
         risk_name=req.criteria.name,
-        criterion=criteria_with_options_DTO_to_BO_mapper(
-            cast(CriteriaWithOptionsDTO, req.criteria)
-        ),
+        criterion=req.criteria.to_criteria(examples=[]),
     )
     return res
 
@@ -298,15 +304,31 @@ async def evaluate(
 
     @handle_llm_generation_exceptions
     def run():
-        inference_engine: InferenceEngine = get_inference_engine_from_judge_metadata(
-            evaluator_name=evaluator_name,
-            custom_model_name=custom_model_name,
-            provider=req.provider,
-            llm_provider_credentials=req.llm_provider_credentials,
-            custom_params={
-                **DEFAULT_JUDGE_INFERENCE_PARAMS,
-            },
-        )
+        if (
+            req.judge_params["self_consistency"] is True
+            or req.judge_params["self_consistency"] > 1
+        ):
+            temperature = 1.0
+        else:
+            temperature = 0.0
+
+        judge_class = JUDGE_CLASS_MAP[req.type][req.judge]
+        judge_requires_model = issubclass(judge_class, UnitxtInferenceEngineMixin)
+
+        if judge_requires_model:
+            inference_engine: InferenceEngine = (
+                get_inference_engine_from_judge_metadata(
+                    evaluator_name=evaluator_name,
+                    custom_model_name=custom_model_name,
+                    provider=req.provider,
+                    llm_provider_credentials=req.llm_provider_credentials,
+                    custom_params={
+                        **DEFAULT_JUDGE_INFERENCE_PARAMS,
+                        "temperature": temperature,
+                    },
+                )
+            )
+
         if (
             req.criteria.to_evaluate_field is None
             or req.criteria.context_fields is None
@@ -319,20 +341,22 @@ async def evaluate(
             dto_instance.to_instance(req.criteria.to_evaluate_field)
             for dto_instance in req.instances
         ]
+        examples = [
+            example.to_instance_result(req.criteria.to_evaluate_field)
+            for example in req.examples
+        ]
+
+        params = req.judge_params
+        if judge_requires_model:
+            params["inference_engine"] = inference_engine  # type: ignore
+
+        judge = judge_class(**params)  # type: ignore
 
         if req.type == EvaluatorTypeEnum.DIRECT:
-            criteria = criteria_with_options_DTO_to_BO_mapper(
-                cast(CriteriaWithOptionsDTO, req.criteria)
-            )
+            criteria = req.criteria.to_criteria(examples=examples)
             if evaluator_name.name.startswith("GRANITE_GUARDIAN"):
-                evaluator = GraniteGuardianJudge(inference_engine=inference_engine)
-            else:
-                evaluator = DirectJudge(
-                    inference_engine=inference_engine,
-                    generate_feedback=True,
-                    check_positional_bias=True,
-                )
-            per_instance_result = evaluator.evaluate(
+                judge = GraniteGuardianJudge(inference_engine=inference_engine)  # type: ignore
+            per_instance_result = judge.evaluate(
                 instances=instances,
                 criteria=criteria,
             )
@@ -342,13 +366,9 @@ async def evaluate(
                 description=req.criteria.description,
                 to_evaluate_field=req.criteria.to_evaluate_field,
                 context_fields=req.criteria.context_fields,
+                examples=examples,
             )
-            evaluator = PairwiseJudge(
-                inference_engine=inference_engine,
-                check_positional_bias=True,
-            )
-
-            per_instance_result = evaluator.evaluate(
+            per_instance_result = judge.evaluate(
                 instances=instances,
                 criteria=criteria,
             )
@@ -356,7 +376,7 @@ async def evaluate(
         # Add the id to each instance result
         res = []
         for instance_result, instance in zip(per_instance_result, req.instances):
-            res.append(InstanceResultDTO(id=instance.id, result=instance_result))
+            res.append(InstanceResultWithId(id=instance.id, result=instance_result))
 
         return EvaluationResultDTO(results=res)
 
@@ -500,24 +520,39 @@ def cleanup_file(filepath: str):
 
 @router.post("/download-notebook/")
 def download_notebook(params: NotebookParams, background_tasks: BackgroundTasks):
-    # Validate inputs
-    if (
-        not hasattr(params, "criteria")
-        or not hasattr(params, "evaluator_name")
-        or not hasattr(params, "predictions")
-        or not hasattr(params, "context_variables")
-    ):
-        raise HTTPException(status_code=400, detail="Missing required fields")
+    instances = [
+        dto_instance.to_instance(params.criteria.to_evaluate_field)
+        for dto_instance in params.instances
+    ]
+    examples = [
+        example.to_instance_result(params.criteria.to_evaluate_field)
+        for example in params.examples
+    ]
+    criteria = params.criteria.to_criteria(examples=examples)
+
     evaluator_name, custom_model_name = init_evaluator_name(params.evaluator_name)
     evaluator_metadata = get_evaluator_metadata_wrapper(
         evaluator_name, custom_model_name
     )
     model_name = get_model_name_from_evaluator(evaluator_metadata, params.provider)
-    params.model_name = model_name
+    p = {
+        "instances": instances,
+        "criteria": criteria,
+        "test_case_name": params.test_case_name,
+        "evaluator_name": evaluator_name,
+        "provider": params.provider,
+        "credentials": params.credentials,
+        "evaluator_type": params.evaluator_type,
+        "model_name": model_name,
+        "plain_python_script": params.plain_python_script,
+        "judge": params.judge,
+        "judge_params": params.judge_params,
+    }
+
     if params.evaluator_type == EvaluatorTypeEnum.DIRECT:
-        nb = DirectEvaluationNotebook(params).generate_notebook()
+        nb = DirectEvaluationNotebook(**p).generate_notebook()  # type: ignore
     else:
-        nb = PairwiseEvaluationNotebook(params).generate_notebook()
+        nb = PairwiseEvaluationNotebook(**p).generate_notebook()  # type: ignore
     from nbconvert import PythonExporter
 
     result_content_file = nb
