@@ -11,14 +11,13 @@ from typing import Any, cast
 
 from botocore.exceptions import NoCredentialsError
 from datasets import IterableDataset
-from evalassist.judges import Criteria, CriteriaOption
+from evalassist.judges import Criteria
 from fastapi import HTTPException
 from ibm_watsonx_ai.wml_client_error import (
     ApiRequestFailure,
     CannotSetProjectOrSpace,
     WMLClientError,
 )
-from langchain_core.exceptions import OutputParserException
 from openai import AuthenticationError, NotFoundError
 from unitxt.inference import (
     CrossProviderInferenceEngine,
@@ -30,7 +29,6 @@ from unitxt.inference import (
 )
 from unitxt.llm_as_judge import EvaluatorNameEnum, ModelProviderEnum
 
-from .api_types import CriteriaWithOptionsDTO
 from .const import CUSTOM_MODELS_PATH, EVAL_ASSIST_DIR
 from .extended_unitxt import (
     EXTENDED_EVALUATOR_TO_MODEL_ID,
@@ -113,7 +111,7 @@ def get_cross_inference_engine_params(
     provider_specific_params: dict | None = None,
 ):
     provider_specific_args = {}
-    inference_engine_params = {
+    inference_engine_params: dict[str, Any] = {
         "max_tokens": 1024,
         "credentials": credentials.copy(),
         "provider": provider,
@@ -435,12 +433,7 @@ def parse_exception_message(e: Exception) -> str:
 
 def handle_exception(e: Exception) -> None:
     error_message = parse_exception_message(e)
-    if isinstance(e, OutputParserException):
-        raise HTTPException(
-            status_code=400,
-            detail=error_message,
-        ) from e
-    elif isinstance(e, NotFoundError):
+    if isinstance(e, NotFoundError):
         raise HTTPException(status_code=400, detail=error_message)
     elif isinstance(e, ValueError):
         raise HTTPException(status_code=400, detail=error_message)
@@ -598,21 +591,6 @@ def get_inference_engine_from_judge_metadata(
     )
 
 
-def criteria_with_options_DTO_to_BO_mapper(
-    criteria: CriteriaWithOptionsDTO,
-) -> Criteria:
-    return Criteria(
-        name=criteria.name,
-        description=criteria.description,
-        options=[
-            CriteriaOption(name=o.name, description=o.description)
-            for o in criteria.options
-        ],
-        to_evaluate_field=criteria.to_evaluate_field,
-        context_fields=criteria.context_fields,
-    )
-
-
 def convert_nan_to_none(obj):
     if isinstance(obj, float) and math.isnan(obj):
         return None
